# zonda-rotgrid

## Installation

```bash
pip install .
```

## Usage

After installation, use the command line tool:

```bash
create-rotated-grid --dx 12.1 --dy 12.1 --center_lat -0.77 --center_lon -5.11 --hwidth_lat 25.025 --hwidth_lon 24.365 --pole_lat 39.25 --pole_lon -162 --ncells_boundary 16 --output output.nc
```

Replace the arguments as needed for your domain.

## License

MIT